@@ -4,10 +4,10 @@ from distutils import log, version
 from contextlib import closing
 
 try:
-    from urlparse import urlsplit, urljoin, unquote
+    from urlparse import urljoin, unquote
     from urllib import urlretrieve, urlopen, urlcleanup
 except ImportError:
-    from urllib.parse import urlsplit, urljoin, unquote
+    from urllib.parse import urljoin, unquote
     from urllib.request import urlretrieve, urlopen, urlcleanup
 
 multi_make_options = []
@@ -56,9 +56,12 @@ def download_and_extract_zlatkovic_binaries(destdir):
     for libname, libfn in libs.items():
         srcfile = urljoin(url, libfn)
         destfile = os.path.join(destdir, libfn)
-        print('Retrieving "%s" to "%s"' % (srcfile, destfile))
-        urlcleanup()  # work around FTP bug 27973 in Py2.7.12+
-        urlretrieve(srcfile, destfile)
+        if os.path.exists(destfile + ".keep"):
+            print('Using local copy of  "{}"'.format(srcfile))
+        else:
+            print('Retrieving "%s" to "%s"' % (srcfile, destfile))
+            urlcleanup()  # work around FTP bug 27973 in Py2.7.12+
+            urlretrieve(srcfile, destfile)
         d = unpack_zipfile(destfile, destdir)
         libs[libname] = d
 
@@ -276,23 +279,11 @@ def unpack_tarball(tar_filename, dest):
 
 
 def call_subprocess(cmd, **kw):
-    try:
-        from subprocess import proc_call
-    except ImportError:
-        # no subprocess for Python 2.3
-        def proc_call(cmd, **kwargs):
-            cwd = kwargs.get('cwd', '.')
-            old_cwd = os.getcwd()
-            try:
-                os.chdir(cwd)
-                return os.system(' '.join(cmd))
-            finally:
-                os.chdir(old_cwd)
-
+    import subprocess
     cwd = kw.get('cwd', '.')
     cmd_desc = ' '.join(cmd)
     log.info('Running "%s" in %s' % (cmd_desc, cwd))
-    returncode = proc_call(cmd, **kw)
+    returncode = subprocess.call(cmd, **kw)
     if returncode:
         raise Exception('Command "%s" returned code %s' % (cmd_desc, returncode))
 
