@@ -2,20 +2,21 @@
 
 """
 Tests for the incremental XML serialisation API.
-
-Tests require Python 2.5 or later.
 """
 
-from __future__ import with_statement
+from __future__ import with_statement, absolute_import
 
 import unittest
 import tempfile, os, sys
 
+from lxml.etree import LxmlSyntaxError
+
 this_dir = os.path.dirname(__file__)
 if this_dir not in sys.path:
     sys.path.insert(0, this_dir) # needed for Py3
 
-from common_imports import etree, BytesIO, HelperTestCase, skipIf
+from .common_imports import etree, BytesIO, HelperTestCase, skipIf, _str
+
 
 class _XmlFileTestCaseBase(HelperTestCase):
     _file = None  # to be set by specific subtypes below
@@ -285,6 +286,7 @@ class TempXmlFileTestCase(_XmlFileTestCaseBase):
         self._file = tempfile.TemporaryFile()
 
 
+@skipIf(sys.platform.startswith("win"), "Can't reopen temporary files on Windows")
 class TempPathXmlFileTestCase(_XmlFileTestCaseBase):
     def setUp(self):
         self._tmpfile = tempfile.NamedTemporaryFile()
@@ -380,8 +382,29 @@ class HtmlFileTestCase(_XmlFileTestCaseBase):
             self.assertXml('<%s>' % tag)
             self._file = BytesIO()
 
+    def test_method_context_manager_misuse(self):
+        with etree.htmlfile(self._file) as xf:
+            with xf.element('foo'):
+                cm = xf.method('xml')
+                cm.__enter__()
+
+                self.assertRaises(LxmlSyntaxError, cm.__enter__)
+
+                cm2 = xf.method('xml')
+                cm2.__enter__()
+                cm2.__exit__(None, None, None)
+
+                self.assertRaises(LxmlSyntaxError, cm2.__exit__, None, None, None)
+
+                cm3 = xf.method('xml')
+                cm3.__enter__()
+                with xf.method('html'):
+                    self.assertRaises(LxmlSyntaxError, cm3.__exit__, None, None, None)
+
     def test_xml_mode_write_inside_html(self):
-        elt = etree.Element("foo", attrib={'selected': 'bar'})
+        tag = 'foo'
+        attrib = {'selected': 'bar'}
+        elt = etree.Element(tag, attrib=attrib)
 
         with etree.htmlfile(self._file) as xf:
             with xf.element("root"):
@@ -393,11 +416,22 @@ class HtmlFileTestCase(_XmlFileTestCaseBase):
                 elt.text = ""
                 xf.write(elt, method='xml')  # 3
 
+                with xf.element(tag, attrib=attrib, method='xml'):
+                    pass # 4
+
+                xf.write(elt)  # 5
+
+                with xf.method('xml'):
+                    xf.write(elt)  # 6
+
         self.assertXml(
             '<root>'
                 '<foo selected></foo>'  # 1
                 '<foo selected="bar"/>'  # 2
                 '<foo selected="bar"></foo>'  # 3
+                '<foo selected="bar"></foo>'  # 4
+                '<foo selected></foo>'  # 5
+                '<foo selected="bar"></foo>'  # 6
             '</root>')
         self._file = BytesIO()
 
@@ -418,6 +452,34 @@ class HtmlFileTestCase(_XmlFileTestCaseBase):
             '</root>')
         self._file = BytesIO()
 
+    def test_attribute_quoting(self):
+        with etree.htmlfile(self._file) as xf:
+            with xf.element("tagname", attrib={"attr": '"misquoted"'}):
+                xf.write("foo")
+
+        self.assertXml('<tagname attr="&quot;misquoted&quot;">foo</tagname>')
+
+    def test_attribute_quoting_unicode(self):
+        with etree.htmlfile(self._file) as xf:
+            with xf.element("tagname", attrib={"attr": _str('"misquöted\\u3344\\U00013344"')}):
+                xf.write("foo")
+
+        self.assertXml('<tagname attr="&quot;misqu&#xF6;ted&#x3344;&#x13344;&quot;">foo</tagname>')
+
+    def test_unescaped_script(self):
+        with etree.htmlfile(self._file) as xf:
+            elt = etree.Element('script')
+            elt.text = "if (a < b);"
+            xf.write(elt)
+        self.assertXml('<script>if (a < b);</script>')
+
+    def test_unescaped_script_incremental(self):
+        with etree.htmlfile(self._file) as xf:
+            with xf.element('script'):
+                xf.write("if (a < b);")
+
+        self.assertXml('<script>if (a < b);</script>')
+
     def test_write_declaration(self):
         with etree.htmlfile(self._file) as xf:
             try:
