@@ -247,7 +247,6 @@ class ETreeXSLTTestCase(HelperTestCase):
         st = etree.XSLT(root_node[0])
 
     def test_xslt_broken(self):
-        tree = self.parse('<a/>')
         style = self.parse('''\
 <xsl:stylesheet version="1.0"
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
@@ -256,9 +255,18 @@ class ETreeXSLTTestCase(HelperTestCase):
         self.assertRaises(etree.XSLTParseError,
                           etree.XSLT, style)
 
+    def _test_xslt_error_log(self):
+        tree = self.parse('<a/>')
+        style = self.parse('''\
+<xsl:stylesheet version="1.0"
+    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+    <xsl:foo />
+</xsl:stylesheet>''')
+        self.assertRaises(etree.XSLTParseError,
+                          etree.XSLT, style)
         exc = None
         try:
-            etree.XSLT(style)
+            etree.XSLT(tree)
         except etree.XSLTParseError as e:
             exc = e
         else:
@@ -1195,7 +1203,7 @@ class ETreeEXSLTTestCase(HelperTestCase):
     <test>
       <xsl:for-each select="regexp:match(
             'http://www.bayes.co.uk/xml/index.xml?/xml/utils/rechecker.xml',
-            '(\w+):\/\/([^/:]+)(:\d*)?([^# ]*)')">
+            '(\\w+):\\/\\/([^/:]+)(:\\d*)?([^# ]*)')">
         <test1><xsl:value-of select="."/></test1>
       </xsl:for-each>
     </test>
@@ -1230,7 +1238,7 @@ class ETreeEXSLTTestCase(HelperTestCase):
   <xsl:template match="/">
     <test>
       <xsl:for-each select="regexp:match(
-            'This is a test string', '(\w+)', 'g')">
+            'This is a test string', '(\\w+)', 'g')">
         <test1><xsl:value-of select="."/></test1>
       </xsl:for-each>
     </test>
